@@ -1,12 +1,11 @@
 /* Test for assigning compile-time constant-string objects to static variables.  */
 /* Contributed by Ziemowit Laski <zlaski@apple.com>  */
 
-/* { dg-options "-fnext-runtime -fconstant-string-class=Foo -lobjc" } */
+/* { dg-options "-fconstant-string-class=Foo" } */
 /* { dg-do run { target *-*-darwin* } } */
 
-
+#include "../objc-obj-c++-shared/Object1.h"
 #include <stdlib.h>
-#include <objc/Object.h>
 
 @interface Foo: Object {
   char *cString;
@@ -14,7 +13,11 @@
 }
 @end
 
+#ifdef NEXT_OBJC_USE_NEW_INTERFACE
+Class _FooClassReference;
+#else
 struct objc_class _FooClassReference;
+#endif
 
 @implementation Foo : Object
 - (char *)customString {
@@ -37,3 +40,5 @@ int main () {
   PrefsSynchronize();
   return 0;
 }
+
+#include "../objc-obj-c++-shared/Object1-implementation.h"
