@@ -1,8 +1,12 @@
 /* Based on a test case contributed by Nicola Pero.  */
 
+#import "../../objc-obj-c++-shared/next-mapping.h"
 #include <string.h>
 #include <stdlib.h>
+
+#ifndef __NEXT_RUNTIME__
 #include <objc/NXConstStr.h>
+#endif
 
 #define STRING "this is a string"
 
